__version__ = "0.0.4"

from bytetype.units import (
    BYTE, KILOBYTE, MEGABYTE, GIGABYTE, TERABYTE,
    PETABYTE, EXABYTE, ZETTABYTE, YOTTABYTE
)

from bytetype.utils import (
    bytes_idx, bytes_to_size
)

from bytetype.enums import (
    ByteSize, BytesUnit
)

from bytetype.bytes import (Bytes)

__all__ = ['Bytes', 'ByteSize', 'BytesUnit', 'bytes_idx', 'bytes_to_size',]


# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/bytetype',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/bytetype',
                'lib_path': 'bytetype'},
  'syms': { 'bytetype.bytes': { 'bytetype.bytes.Bytes': ('bytes.html#bytes', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__add__': ('bytes.html#bytes.__add__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__eq__': ('bytes.html#bytes.__eq__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__ge__': ('bytes.html#bytes.__ge__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__gt__': ('bytes.html#bytes.__gt__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__le__': ('bytes.html#bytes.__le__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__lt__': ('bytes.html#bytes.__lt__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__mul__': ('bytes.html#bytes.__mul__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__ne__': ('bytes.html#bytes.__ne__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__post_init__': ('bytes.html#bytes.__post_init__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__repr__': ('bytes.html#bytes.__repr__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__sub__': ('bytes.html#bytes.__sub__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__truediv__': ('bytes.html#bytes.__truediv__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.from_dir': ('bytes.html#bytes.from_dir', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.from_file': ('bytes.html#bytes.from_file', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.to_bytes': ('bytes.html#bytes.to_bytes', 'bytetype/bytes.py')},
            'bytetype.core': { 'bytetype.core.Bytes': ('core.html#bytes', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__add__': ('core.html#bytes.__add__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__eq__': ('core.html#bytes.__eq__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__ge__': ('core.html#bytes.__ge__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__gt__': ('core.html#bytes.__gt__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__le__': ('core.html#bytes.__le__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__lt__': ('core.html#bytes.__lt__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__mul__': ('core.html#bytes.__mul__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__ne__': ('core.html#bytes.__ne__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__post_init__': ('core.html#bytes.__post_init__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__repr__': ('core.html#bytes.__repr__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__sub__': ('core.html#bytes.__sub__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__truediv__': ('core.html#bytes.__truediv__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.from_dir': ('core.html#bytes.from_dir', 'bytetype/core.py'),
                               'bytetype.core.Bytes.from_file': ('core.html#bytes.from_file', 'bytetype/core.py'),
                               'bytetype.core.Bytes.to_bytes': ('core.html#bytes.to_bytes', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit': ('core.html#bytesunit', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.calc_idx': ('core.html#bytesunit.calc_idx', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.calc_size': ('core.html#bytesunit.calc_size', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.from_bytes': ('core.html#bytesunit.from_bytes', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.keys': ('core.html#bytesunit.keys', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.unit': ('core.html#bytesunit.unit', 'bytetype/core.py'),
                               'bytetype.core.bytes_idx': ('core.html#bytes_idx', 'bytetype/core.py'),
                               'bytetype.core.bytes_to_size': ('core.html#bytes_to_size', 'bytetype/core.py')},
            'bytetype.enums': { 'bytetype.enums.ByteSize': ('enums.html#bytesize', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit': ('enums.html#bytesunit', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.calc_idx': ('enums.html#bytesunit.calc_idx', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.calc_size': ('enums.html#bytesunit.calc_size', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.from_bytes': ('enums.html#bytesunit.from_bytes', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.keys': ('enums.html#bytesunit.keys', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.unit': ('enums.html#bytesunit.unit', 'bytetype/enums.py')},
            'bytetype.units': {},
            'bytetype.utils': { 'bytetype.utils.bytes_idx': ('utils.html#bytes_idx', 'bytetype/utils.py'),
                                'bytetype.utils.bytes_to_size': ('utils.html#bytes_to_size', 'bytetype/utils.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_bytes.ipynb.

# %% auto 0
__all__ = ['Bytes']

# %% ../nbs/03_bytes.ipynb 4
import os, math
from dataclasses import KW_ONLY, dataclass, field
from typing import Union, List, Optional

# %% ../nbs/03_bytes.ipynb 6
from bytetype.units import (
    BYTE, KILOBYTE, MEGABYTE, GIGABYTE, TERABYTE,
    PETABYTE, EXABYTE, ZETTABYTE, YOTTABYTE
)

# %% ../nbs/03_bytes.ipynb 8
from bytetype.utils import (
    bytes_idx, bytes_to_size
)

# %% ../nbs/03_bytes.ipynb 10
from bytetype.enums import (
    ByteSize, BytesUnit
)

# %% ../nbs/03_bytes.ipynb 12
@dataclass
class Bytes:
    """A class for representing sizes in various byte units."""
    nbytes: int = field(default=0, repr=False,)
    round: Optional[int] = field(default=2, repr=False)
    
    unit: BytesUnit = field(default=BytesUnit.B, init=False)
    size: float = field(default=0.0, init=False)

    def __post_init__(self):
        self.unit = BytesUnit.from_bytes(self.nbytes)
        self.size = BytesUnit.calc_size(self.nbytes, self.round)

    def __repr__(self) -> str:
        return f'{self.size} {self.unit}'
    
    def __add__(self, other: Union['Bytes', int]):
        """Add two Bytes instances or a Bytes instance and a byte count.
        
        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        Bytes
            The Bytes instance representing the total size.
        """
        if isinstance(other, Bytes):
            total_bytes = self.nbytes + other.nbytes
        else:
            total_bytes = self.nbytes + other
        return Bytes(total_bytes, round=self.round)

    def __sub__(self, other: Union['Bytes', int]):
        """Subtract a Bytes instance or a byte count from this Bytes instance.
        
        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        Bytes
            The Bytes instance representing the remaining size.
        """
        if isinstance(other, Bytes):
            total_bytes = self.nbytes - other.nbytes
        else:
            total_bytes = self.nbytes - other
        if total_bytes < 0: total_bytes = 0
        return Bytes(total_bytes, round=self.round)
    
    def __mul__(self, other: Union['Bytes', int]):
        """Multiply this Bytes instance by a Bytes instance or a byte count.
        
        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        Bytes
            The Bytes instance representing the total size.
        """
        if isinstance(other, Bytes):
            total_bytes = self.nbytes * other.nbytes
        else:
            total_bytes = self.nbytes * other
        return Bytes(total_bytes, round=self.round)

    def __truediv__(self, other: Union['Bytes', int]):
        """Divide this Bytes instance by a Bytes instance or a byte count.
        
        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        Bytes
            The Bytes instance representing the total size.
        """
        if isinstance(other, Bytes):
            total_bytes = self.nbytes / other.nbytes
        else:
            total_bytes = self.nbytes / other
        return Bytes(total_bytes, round=self.decimals)

    @staticmethod
    def from_file(file_path: str, round: Optional[int] = 2) -> 'Bytes':
        """Create a Bytes instance representing the size of a file.
        
        Parameters
        ----------
        file_path : str
            The path to the file.
        decimals : int, optional
            The number of decimal places to round to (default is 2).

        Returns
        -------
        Bytes
            The Bytes instance representing the size of the file.
        """
        size = os.path.getsize(file_path)
        return Bytes(size, round=round)

    @staticmethod
    def from_dir(dir_path: str, round: Optional[int] = 2) -> 'Bytes':
        """Create a Bytes instance representing the total size of a directory.
        
        Parameters
        ----------
        dir_path : str
            The path to the directory.
        decimals : int, optional
            The number of decimal places to round to (default is 2).

        Returns
        -------
        Bytes
            The Bytes instance representing the total size of the directory.
        """
        total = 0
        for dirpath, dirnames, filenames in os.walk(dir_path):
            for f in filenames:
                fp = os.path.join(dirpath, f)
                if not os.path.islink(fp):
                    total += os.path.getsize(fp)
        return Bytes(total, round=round)
    
    def to_bytes(self) -> int:
        """Convert the Bytes instance to a byte count.

        Returns
        -------
        int
            The byte count.
        """
        return self.nbytes
    

    def __lt__(self, other: Union['Bytes', int]) -> bool:
        """Less than comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is less than the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.nbytes < other.nbytes
        else:
            return self.nbytes < other

    def __le__(self, other: Union['Bytes', int]) -> bool:
        """Less than or equal to comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is less than or equal to the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.nbytes <= other.nbytes
        else:
            return self.nbytes <= other

    def __gt__(self, other: Union['Bytes', int]) -> bool:
        """Greater than comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is greater than the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.nbytes > other.nbytes
        else:
            return self.nbytes > other

    def __ge__(self, other: Union['Bytes', int]) -> bool:
        """Greater than or equal to comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is greater than or equal to the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.nbytes >= other.nbytes
        else:
            return self.nbytes >= other

    def __eq__(self, other: Union['Bytes', int]) -> bool:
        """Equality comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is equal to the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.nbytes == other.nbytes
        else:
            return self.nbytes == other

    def __ne__(self, other: Union['Bytes', int]) -> bool:
        """Not equal to comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is not equal to the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.nbytes != other.nbytes
        else:
            return self.nbytes != other



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_enums.ipynb.

# %% auto 0
__all__ = ['ByteSize', 'BytesUnit']

# %% ../nbs/02_enums.ipynb 4
import os, math
from typing import Union, List, Optional

# %% ../nbs/02_enums.ipynb 5
from litum import LitIntEnum, LitStrEnum, set_dtype, set_fallback

# %% ../nbs/02_enums.ipynb 7
from bytetype.units import (
    BYTE, KILOBYTE, MEGABYTE, GIGABYTE, TERABYTE,
    PETABYTE, EXABYTE, ZETTABYTE, YOTTABYTE
)

# %% ../nbs/02_enums.ipynb 9
from bytetype.utils import (
    bytes_idx, bytes_to_size
)

# %% ../nbs/02_enums.ipynb 12
@set_dtype(int)
@set_fallback('KB')
class ByteSize(LitIntEnum):
    """An enumeration of byte size.
    
    This class defines an int enumeration representing various byte size.    
    """
    B  = BYTE
    KB = KILOBYTE
    MB = MEGABYTE
    GB = GIGABYTE
    TB = TERABYTE
    PB = PETABYTE
    EB = EXABYTE
    ZB = ZETTABYTE
    YB = YOTTABYTE

# %% ../nbs/02_enums.ipynb 14
@set_dtype(str)
@set_fallback('B')
class BytesUnit(LitStrEnum):
    """An enumeration of byte units.
    
    This class defines a string enumeration representing various byte units.
    It provides methods for calculating size and determining appropriate unit from a byte count.
    """
    B = 'B'
    KB = 'KB'
    MB = 'MB'
    GB = 'GB'
    TB = 'TB'
    PB = 'PB'
    EB = 'EB'
    ZB = 'ZB'
    YB = 'YB'

    @staticmethod
    def calc_idx(nbytes: float) -> int:
        """Calculate the index of the byte unit for a byte count.
        
        Parameters
        ----------
        nbytes : float
            The byte count.

        Returns
        -------
        int
            The index of the byte unit.
        """
        return bytes_idx(nbytes)
    
    @staticmethod
    def calc_size(nbytes: float, decimals: Optional[int] = 2) -> float:
        """Calculate the size in appropriate byte unit for a byte count.
        
        Parameters
        ----------
        nbytes : float
            The byte count.
        decimals : int, optional
            The number of decimal places to round to (default is 2).

        Returns
        -------
        float
            The size in the appropriate byte unit.
        """
        return bytes_to_size(nbytes, decimals)

    @classmethod
    def unit(cls, nbytes: float) -> str:
        """Determine the appropriate byte unit for a byte count.
        
        Parameters
        ----------
        nbytes : float
            The byte count.

        Returns
        -------
        str
            The appropriate byte unit.
        """
        idx = cls.calc_idx(nbytes)
        key = cls.keys()[idx]    
        return key
    
    @classmethod
    def keys(cls) -> List[str]:
        """Get the keys of the enumeration.

        Returns
        -------
        List[str]
            The keys of the enumeration.
        """
        return list(cls._member_map_.keys())
    
    @classmethod
    def from_bytes(cls, nbytes: float) -> 'BytesUnit':
        """Create a BytesUnit instance from a byte count.
        
        Parameters
        ----------
        nbytes : float
            The byte count.

        Returns
        -------
        BytesUnit
            The BytesUnit instance representing the appropriate byte unit.
        """
        unit = cls.unit(nbytes)
        return cls(unit)



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_utils.ipynb.

# %% auto 0
__all__ = ['bytes_idx', 'bytes_to_size']

# %% ../nbs/01_utils.ipynb 4
import os, math
from dataclasses import KW_ONLY, dataclass, field
from enum import Enum, StrEnum, IntEnum
from typing import Union, List, Optional

# %% ../nbs/01_utils.ipynb 6
from bytetype.units import (
    BYTE, KILOBYTE, MEGABYTE, GIGABYTE, TERABYTE,
    PETABYTE, EXABYTE, ZETTABYTE, YOTTABYTE
)

# %% ../nbs/01_utils.ipynb 8
def bytes_idx(nbytes: float) -> int:
    """Calculate the index of the byte unit for a byte count.

    Parameters
    ----------
    nbytes : float
        The byte count.

    Returns
    -------
    int
        The index of the byte unit.
    """
    idx = int(math.floor(math.log(nbytes, KILOBYTE)))
    return idx

# %% ../nbs/01_utils.ipynb 9
def bytes_to_size(nbytes: float, decimals: Optional[int] = 2) -> float:
    """Calculate the size in appropriate byte unit for a byte count.

    Parameters
    ----------
    nbytes : float
        The byte count.
    decimals : int, optional
        The number of decimal places to round to (default is 2).

    Returns
    -------
    float
        The size in the appropriate byte unit.
    """
    idx = bytes_idx(nbytes)
    power = math.pow(KILOBYTE, idx)
    size = round(nbytes / power, decimals)
    return size



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_core.ipynb.

# %% auto 0
__all__ = ['KILOBYTE', 'bytes_idx', 'bytes_to_size', 'BytesUnit', 'Bytes']

# %% ../nbs/00_core.ipynb 3
import os, math
from dataclasses import KW_ONLY, dataclass, field
from enum import StrEnum
from typing import Union, List, Optional

# %% ../nbs/00_core.ipynb 4
KILOBYTE = 1024

# %% ../nbs/00_core.ipynb 5
def bytes_idx(bytes:float) -> int:
    """Calculate the index of the byte unit for a byte count.

    Parameters
    ----------
    bytes : float
        The byte count.

    Returns
    -------
    int
        The index of the byte unit.
    """
    idx = int(math.floor(math.log(bytes, KILOBYTE)))
    return idx

def bytes_to_size(bytes:float, decimals: Optional[int] = 2) -> float:
    """Calculate the size in appropriate byte unit for a byte count.

    Parameters
    ----------
    bytes : float
        The byte count.
    decimals : int, optional
        The number of decimal places to round to (default is 2).

    Returns
    -------
    float
        The size in the appropriate byte unit.
    """
    idx = bytes_idx(bytes)
    power = math.pow(KILOBYTE, idx)
    size = round(bytes / power, decimals)
    return size

# %% ../nbs/00_core.ipynb 6
class BytesUnit(StrEnum):
    """An enumeration of byte units.
    
    This class defines a string enumeration representing various byte units.
    It provides methods for calculating size and determining appropriate unit from a byte count.
    """
    B = 'B'
    KB = 'KB'
    MB = 'MB'
    GB = 'GB'
    TB = 'TB'
    PB = 'PB'
    EB = 'EB'
    ZB = 'ZB'
    YB = 'YB'

    @staticmethod
    def calc_idx(bytes:float) -> int:
        """Calculate the index of the byte unit for a byte count.
        
        Parameters
        ----------
        bytes : float
            The byte count.

        Returns
        -------
        int
            The index of the byte unit.
        """
        return bytes_idx(bytes)
    
    @staticmethod
    def calc_size(bytes:float, decimals: Optional[int] = 2) -> float:
        """Calculate the size in appropriate byte unit for a byte count.
        
        Parameters
        ----------
        bytes : float
            The byte count.
        decimals : int, optional
            The number of decimal places to round to (default is 2).

        Returns
        -------
        float
            The size in the appropriate byte unit.
        """
        return bytes_to_size(bytes, decimals)

    @classmethod
    def unit(cls, bytes:float) -> str:
        """Determine the appropriate byte unit for a byte count.
        
        Parameters
        ----------
        bytes : float
            The byte count.

        Returns
        -------
        str
            The appropriate byte unit.
        """
        idx = cls.calc_idx(bytes)
        key = cls.keys()[idx]    
        return key
    
    @classmethod
    def keys(cls) -> List[str]:
        """Get the keys of the enumeration.

        Returns
        -------
        List[str]
            The keys of the enumeration.
        """
        return list(cls._member_map_.keys())
    
    @classmethod
    def from_bytes(cls, bytes:float) -> 'BytesUnit':
        """Create a BytesUnit instance from a byte count.
        
        Parameters
        ----------
        bytes : float
            The byte count.

        Returns
        -------
        BytesUnit
            The BytesUnit instance representing the appropriate byte unit.
        """
        unit = cls.unit(bytes)
        return cls(unit)

# %% ../nbs/00_core.ipynb 7
@dataclass
class Bytes:
    """A class for representing sizes in various byte units."""
    bytes: int = field(default=0, repr=False,)
    round: Optional[int] = field(default=2, repr=False)
    
    unit: BytesUnit = field(default=BytesUnit.B, init=False)
    size: float = field(default=0.0, init=False)

    def __post_init__(self):
        self.unit = BytesUnit.from_bytes(self.bytes)
        self.size = BytesUnit.calc_size(self.bytes, self.round)

    def __repr__(self) -> str:
        return f'{self.size} {self.unit}'
    
    def __add__(self, other: Union['Bytes', int]):
        """Add two Bytes instances or a Bytes instance and a byte count.
        
        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        Bytes
            The Bytes instance representing the total size.
        """
        if isinstance(other, Bytes):
            total_bytes = self.bytes + other.bytes
        else:
            total_bytes = self.bytes + other
        return Bytes(total_bytes, round=self.round)

    def __sub__(self, other: Union['Bytes', int]):
        """Subtract a Bytes instance or a byte count from this Bytes instance.
        
        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        Bytes
            The Bytes instance representing the remaining size.
        """
        if isinstance(other, Bytes):
            total_bytes = self.bytes - other.bytes
        else:
            total_bytes = self.bytes - other
        if total_bytes < 0: total_bytes = 0
        return Bytes(total_bytes, round=self.round)
    
    def __mul__(self, other: Union['Bytes', int]):
        """Multiply this Bytes instance by a Bytes instance or a byte count.
        
        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        Bytes
            The Bytes instance representing the total size.
        """
        if isinstance(other, Bytes):
            total_bytes = self.bytes * other.bytes
        else:
            total_bytes = self.bytes * other
        return Bytes(total_bytes, round=self.round)

    def __truediv__(self, other: Union['Bytes', int]):
        """Divide this Bytes instance by a Bytes instance or a byte count.
        
        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        Bytes
            The Bytes instance representing the total size.
        """
        if isinstance(other, Bytes):
            total_bytes = self.bytes / other.bytes
        else:
            total_bytes = self.bytes / other
        return Bytes(total_bytes, round=self.decimals)

    @staticmethod
    def from_file(file_path: str, round: Optional[int] = 2) -> 'Bytes':
        """Create a Bytes instance representing the size of a file.
        
        Parameters
        ----------
        file_path : str
            The path to the file.
        decimals : int, optional
            The number of decimal places to round to (default is 2).

        Returns
        -------
        Bytes
            The Bytes instance representing the size of the file.
        """
        size = os.path.getsize(file_path)
        return Bytes(size, round=round)

    @staticmethod
    def from_dir(dir_path: str, round: Optional[int] = 2) -> 'Bytes':
        """Create a Bytes instance representing the total size of a directory.
        
        Parameters
        ----------
        dir_path : str
            The path to the directory.
        decimals : int, optional
            The number of decimal places to round to (default is 2).

        Returns
        -------
        Bytes
            The Bytes instance representing the total size of the directory.
        """
        total = 0
        for dirpath, dirnames, filenames in os.walk(dir_path):
            for f in filenames:
                fp = os.path.join(dirpath, f)
                if not os.path.islink(fp):
                    total += os.path.getsize(fp)
        return Bytes(total, round=round)
    
    def to_bytes(self) -> int:
        """Convert the Bytes instance to a byte count.

        Returns
        -------
        int
            The byte count.
        """
        return self.bytes
    

    def __lt__(self, other: Union['Bytes', int]) -> bool:
        """Less than comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is less than the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.bytes < other.bytes
        else:
            return self.bytes < other

    def __le__(self, other: Union['Bytes', int]) -> bool:
        """Less than or equal to comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is less than or equal to the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.bytes <= other.bytes
        else:
            return self.bytes <= other

    def __gt__(self, other: Union['Bytes', int]) -> bool:
        """Greater than comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is greater than the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.bytes > other.bytes
        else:
            return self.bytes > other

    def __ge__(self, other: Union['Bytes', int]) -> bool:
        """Greater than or equal to comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is greater than or equal to the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.bytes >= other.bytes
        else:
            return self.bytes >= other

    def __eq__(self, other: Union['Bytes', int]) -> bool:
        """Equality comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is equal to the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.bytes == other.bytes
        else:
            return self.bytes == other

    def __ne__(self, other: Union['Bytes', int]) -> bool:
        """Not equal to comparison between two Bytes instances or a Bytes instance and a byte count.

        Parameters
        ----------
        other : Bytes or int
            The other Bytes instance or byte count.

        Returns
        -------
        bool
            True if this Bytes instance is not equal to the other, False otherwise.
        """
        if isinstance(other, Bytes):
            return self.bytes != other.bytes
        else:
            return self.bytes != other



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_units.ipynb.

# %% auto 0
__all__ = ['BYTE', 'KILOBYTE', 'MEGABYTE', 'GIGABYTE', 'TERABYTE', 'PETABYTE', 'EXABYTE', 'ZETTABYTE', 'YOTTABYTE']

# %% ../nbs/00_units.ipynb 4
BYTE     : int = 1
KILOBYTE : int = BYTE * 1000
MEGABYTE : int = KILOBYTE ** 2
GIGABYTE : int = KILOBYTE ** 3
TERABYTE : int = KILOBYTE ** 4
PETABYTE : int = KILOBYTE ** 5
EXABYTE  : int = KILOBYTE ** 6
ZETTABYTE: int = KILOBYTE ** 7
YOTTABYTE: int = KILOBYTE ** 8
